@@ -19,6 +19,7 @@ class Dataset:
     true_y: List
     class_names: List[str]
     categorical_map: Dict[int, List[str]]
+    target_column: str
 
 
 class BoundedCoordinates:
@@ -68,6 +69,7 @@ class CausalMetric:
     ci_lower: float
     ci_upper: float
     feature: str
+    feature_value: str
     p_value: float
     point: float
     stderr: float
@@ -77,7 +79,6 @@ class CausalMetric:
 class CausalPolicyGains:
     recommended_policy_gains: float
     treatment_gains: Dict[str, float]
-    treatments: List[str]
 
 
 class CausalPolicyTreeLeaf:
@@ -106,6 +107,8 @@ class CausalData:
     global_effects: List[CausalMetric]
     local_effects: List[List[CausalMetric]]
     policies: List[CausalPolicy]
+    id: str
+    treatment_features: [str]
 
 
 class CounterfactualData:
